@@ -1,17 +1,12 @@
-package Exception::Multistate::BadAction;
-$Exception::Multistate::BadAction::VERSION = '0.008';
-use base qw(Exception::Multistate);
-
-package Exception::Multistate::NotFound;
-$Exception::Multistate::NotFound::VERSION = '0.008';
-use base qw(Exception::Multistate);
-
 package QBit::Application::Model::Multistate::DB;
-$QBit::Application::Model::Multistate::DB::VERSION = '0.008';
+$QBit::Application::Model::Multistate::DB::VERSION = '0.009';
 use qbit;
 
 use base qw(QBit::Application::Model::Multistate);
 
+use Exception::Multistate::BadAction;
+use Exception::Multistate::NotFound;
+
 __PACKAGE__->abstract_methods(
     qw(
       _multistate_db_table
